@@ -18,9 +18,11 @@ import re
 import shutil
 import subprocess
 import time
+
 from datetime import datetime
+from cachetools import LRUCache, cached
 import pandas as pd
-from typing import Any, Callable, Dict, Iterable, List, Sequence, Tuple, _GenericAlias, Union
+from typing import Any, Callable, Dict, Iterable, Iterator, List, Sequence, Tuple, _GenericAlias, Union
 
 import numpy as np
 from pydantic import BaseModel
@@ -60,8 +62,8 @@ class PythonObjectEncoder(json.JSONEncoder):
 
 
 # 将$obj转json string。默认ensure_ascii=False,并用indent=4展示
-def jdumps(obj: Any, encoder=PythonObjectEncoder) -> str:
-    return json.dumps(obj, ensure_ascii=False, indent=4, cls=encoder)
+def jdumps(obj: Any, encoder=PythonObjectEncoder, ensure_ascii=False, indent=4, **kwargs) -> str:
+    return json.dumps(obj, ensure_ascii=ensure_ascii, indent=indent, cls=encoder, **kwargs)
 
 
 # 将$obj转json string 写入$fp。$fp可以是一个文件路径，也可以是一个open函数打开的对象
@@ -159,8 +161,7 @@ def table2json(path, **kwargs):
     if path.endswith("xlsx"):
         df = pd.read_excel(path, **kwargs)
     df.replace(np.nan, None, inplace=True)
-    cols = df.columns.tolist()
-    cols = [e for e in cols if not e.startswith("Unnamed")]
+    cols = [e for e in cols if not str(e).startswith("Unnamed")]
     df = df[cols]
     records = df.to_dict(orient="records")
     return records
@@ -248,6 +249,21 @@ load2list = read2list
 dump = dump2list
 load = read2list
 
+
+@cached(cache=LRUCache(10))
+def _load_with_cache(file_path, last_modified_time, **kwargs):
+    dt_object = datetime.fromtimestamp(last_modified_time)
+    last_modified_time = dt_object.strftime("%Y-%m-%d %H:%M:%S")
+    logger.debug(f"loading file:{file_path} with {last_modified_time=}, {kwargs=}")
+    data = load(file_path, **kwargs)
+    return data
+
+
+def load_with_cache(file_path, **kwargs):
+    last_modified_time = os.path.getmtime(file_path)
+    return _load_with_cache(file_path, last_modified_time, **kwargs)
+
+
 # 递归将obj中的float做精度截断
 
 
@@ -372,7 +388,8 @@ def get_latest_version(package_name: str) -> str:
     pattern = "\(from versions:(.*?)\)"
 
     for item in re.findall(pattern, output):
-        if item is None:
+        item = item.strip()
+        if not item or item == "none":
             return "0.0.1"
 
         # item
@@ -470,3 +487,14 @@ def batch_process_with_save(data: Iterable, func: Callable, file_path: str, batc
     dump(acc, file_path)
     return acc
     # logger.info(history_files)
+
+
+def add_callback2gen(items: Iterator, callback: Callable, **kwargs) -> Iterator:
+    acc = []
+
+    def gen():
+        for item in items:
+            yield item
+            acc.append(item)
+        callback(acc, **kwargs)
+    return gen()
